//==================================================================================
// The information contained herein is the exclusive property of
// Generalplus Technology Co. And shall not be distributed, reproduced,
// or disclosed in whole in part without prior written permission.
//       (C) COPYRIGHT 2010   Generalplus TECHNOLOGY CO.                            
//                   ALL RIGHTS RESERVED
// The entire notice above must be reproduced on all authorized copies.
//==================================================================================
//==========================================================================
// Program Name: BAM.asm
// Applied body: GPL95100UA Series Body
// Programmer  : 
// Description : BAM driver code
// History version
// Rev #     Date       Who     Comments
// -----  -----------  ------   --------------------------------------------
// 1.0       					Oringinal Version
// -----  -----------  ------   --------------------------------------------


//==================================================================================
// Include file area
//==================================================================================
.include GPL951_Body.inc
.include BAM_Define.inc

//=============================================
//Constant Define Area
//=============================================


//=============================================
//RAM Define Area
//=============================================
BAM_RAM:	.section	.ram

//=============================================
//Program Area
//=============================================
BAM_DriverCode: .section	.code


//=============================================
//Public declare Area
//=============================================
.public _BAM_Initial
.public F_BAM_Initial
.public _BAM_Data_Setting
.public F_BAM_Data_Setting
.public _BAM_Start
.public F_BAM_Start
.public _BAM_End
.public F_BAM_End


//************************************************************//
//function : F_BAM_Initial
//Description : Initial BAM
//Parameter : none
//Return : none
//Destory : r1
//************************************************************//
_BAM_Initial: 			.proc
	push bp to [sp]
	call F_BAM_Initial
	pop bp from [sp]
	retf
F_BAM_Initial:
	r1 = [P_IOB_Mux]				//Enable BAM Module	
	r1 |= 0x0008
	[P_IOB_Mux] = r1
.if BAM0
	r1 = 0x0000						//BAM default data
	[P_TimerA_BAM_Data] = r1		
	r1 = 0xFF00						//256 cycle preload
	[P_TimerA_BAM_Cycle] = r1		
	r1 = C_BAM_En + BAM0_Polarity_setting	//BAM output polarity setting
	[P_TimerA_CCP_Ctrl] = r1
	r1 = C_TimerFlag + C_TimerSrcB_High + C_TimerSrcA_SYSdiv2		//source clk setting
	[P_TimerA_Ctrl] = r1		
.endif	
.if BAM1
	r1 = 0x0000						//BAM default data
	[P_TimerB_BAM_Data] = r1		
	r1 = 0xFF00						//256 cycle preload
	[P_TimerB_BAM_Cycle] = r1		
	r1 = C_BAM_En + BAM1_Polarity_setting	//BAM output polarity setting
	[P_TimerB_CCP_Ctrl] = r1
	r1 = C_TimerFlag + C_TimerSrcB_High + C_TimerSrcA_SYSdiv2		//source clk setting
	[P_TimerB_Ctrl] = r1		
.endif	
.if BAM2
	r1 = 0x0000						//BAM default data
	[P_TimerC_BAM_Data] = r1		
	r1 = 0xFF00						//256 cycle preload
	[P_TimerC_BAM_Cycle] = r1		
	r1 = C_BAM_En + BAM2_Polarity_setting	//BAM output polarity setting
	[P_TimerC_CCP_Ctrl] = r1
	r1 = C_TimerFlag + C_TimerSrcB_High + C_TimerSrcA_SYSdiv2		//source clk setting
	[P_TimerC_Ctrl] = r1		
.endif	
.if BAM3
	r1 = 0x0000						//BAM default data
	[P_TimerD_BAM_Data] = r1		
	r1 = 0xFF00						//256 cycle preload
	[P_TimerD_BAM_Cycle] = r1		
	r1 = C_BAM_En + BAM3_Polarity_setting	//BAM output polarity setting
	[P_TimerD_CCP_Ctrl] = r1
	r1 = C_TimerFlag + C_TimerSrcB_High + C_TimerSrcA_SYSdiv2		//source clk setting
	[P_TimerD_Ctrl] = r1		
.endif	
.if BAM4
	r1 = 0x0000						//BAM default data
	[P_TimerE_BAM_Data] = r1		
	r1 = 0xFF00						//256 cycle preload
	[P_TimerE_BAM_Cycle] = r1		
	r1 = C_BAM_En + BAM4_Polarity_setting	//BAM output polarity setting
	[P_TimerE_CCP_Ctrl] = r1
	r1 = C_TimerFlag + C_TimerSrcB_High + C_TimerSrcA_SYSdiv2		//source clk setting
	[P_TimerE_Ctrl] = r1
	r1 = [P_TimerEF_CCP_Sel] 		// BAM4 select TimerE
	r1 &= ~0x0001
	[P_TimerEF_CCP_Sel] = r1		
.endif	
.if BAM5
	r1 = 0x0000						//BAM default data
	[P_TimerF_BAM_Data] = r1		
	r1 = 0xFF00						//256 cycle preload
	[P_TimerF_BAM_Cycle] = r1		
	r1 = C_BAM_En + BAM5_Polarity_setting	//BAM output polarity setting
	[P_TimerF_CCP_Ctrl] = r1
	r1 = C_TimerFlag + C_TimerSrcB_High + C_TimerSrcA_SYSdiv2		//source clk setting
	[P_TimerF_Ctrl] = r1	
	r1 = [P_TimerEF_CCP_Sel] 		// BAM5 select TimerF
	r1 |= 0x0002
	[P_TimerEF_CCP_Sel] = r1		
.endif	
	retf
	.endp


//************************************************************//
//function : F_BAM_Data_Setting
//Description : Set BAM data
//Parameter : r1 : BAM select(High Byte) & BAM data(Low Byte)
//Return : none
//Destory : r1,r2
//************************************************************//
_BAM_Data_Setting:			.proc
	push	bp to [sp]
	bp=sp+1
	r1=[bp+3]					//BAM select & BAM data
	call F_BAM_Data_Setting
	pop bp from [sp]
	retf
F_BAM_Data_Setting:
	r2 = r1
	r1 &= 0xff00
	test r1,0x0100
	jz	L_BAM1_Sel?
	[P_TimerA_BAM_Data] = r2	
L_BAM1_Sel?:	
	test r1,0x0200
	jz	L_BAM2_Sel?
	[P_TimerB_BAM_Data] = r2
L_BAM2_Sel?:	
	test r1,0x0400
	jz	L_BAM3_Sel?
	[P_TimerC_BAM_Data] = r2		
L_BAM3_Sel?:	
	test r1,0x0800
	jz	L_BAM4_Sel?	
	[P_TimerD_BAM_Data] = r2
L_BAM4_Sel?:				
	test r1,0x1000
	jz	L_BAM5_Sel?
	[P_TimerE_BAM_Data] = r2
L_BAM5_Sel?:	
	test r1,0x2000
	jz	L_None_Sel?
	[P_TimerF_BAM_Data] = r2	
L_None_Sel?:	
	retf			
	.endp	
	
//************************************************************//
//function : F_BAM_Start
//Description : Start BAM transmission
//Parameter : r1 : BAM select(High Byte)
//Return : none
//Destory : r1, r2
//************************************************************//
_BAM_Start:			.proc
	push	bp to [sp]
	bp=sp+1
	r1=[bp+3]					//BAM select
	call F_BAM_Start
	pop bp from [sp]
	retf
F_BAM_Start:
	r1 &= 0xff00
	test r1,0x0100
	jz	L_BAM1_Sel?
	r2 = [P_TimerA_Ctrl]
	r2 |= C_TimerEn
	[P_TimerA_Ctrl] = r2
L_BAM1_Sel?:	
	test r1,0x0200
	jz	L_BAM2_Sel?
	r2 = [P_TimerB_Ctrl]
	r2 |= C_TimerEn
	[P_TimerB_Ctrl] = r2
L_BAM2_Sel?:	
	test r1,0x0400
	jz	L_BAM3_Sel?
	r2 = [P_TimerC_Ctrl]
	r2 |= C_TimerEn
	[P_TimerC_Ctrl] = r2		
L_BAM3_Sel?:	
	test r1,0x0800
	jz	L_BAM4_Sel?	
	r2 = [P_TimerD_Ctrl]
	r2 |= C_TimerEn
	[P_TimerD_Ctrl] = r2
L_BAM4_Sel?:			
	test r1,0x1000
	jz	L_BAM5_Sel?	
	r2 = [P_TimerE_Ctrl]
	r2 |= C_TimerEn
	[P_TimerE_Ctrl] = r2
L_BAM5_Sel?:	
	test r1,0x2000
	jz	L_None_Sel?
	r2 = [P_TimerF_Ctrl]
	r2 |= C_TimerEn
	[P_TimerF_Ctrl] = r2
L_None_Sel?:	
	retf			
	.endp
	
	
//************************************************************//
//function : F_BAM_End
//Description : End BAM transmission
//Parameter : r1 : BAM select(High Byte)
//Return : none
//Destory : r1, r2
//************************************************************//
_BAM_End:			.proc
	push	bp to [sp]
	bp=sp+1
	r1=[bp+3]					//BAM select
	call F_BAM_End
	pop bp from [sp]
	retf
F_BAM_End:
	r1 &= 0xff00
	test r1,0x0100
	jz	L_BAM1_Sel?
	r2 = [P_TimerA_Ctrl]
	r2 &= ~C_TimerEn
	[P_TimerA_Ctrl] = r2
L_BAM1_Sel?:	
	test r1,0x0200
	jz	L_BAM2_Sel?
	r2 = [P_TimerB_Ctrl]
	r2 &= ~C_TimerEn
	[P_TimerB_Ctrl] = r2
L_BAM2_Sel?:	
	test r1,0x0400
	jz	L_BAM3_Sel?
	r2 = [P_TimerC_Ctrl]
	r2 &= ~C_TimerEn
	[P_TimerC_Ctrl] = r2		
L_BAM3_Sel?:	
	test r1,0x0800
	jz	L_BAM4_Sel?	
	r2 = [P_TimerD_Ctrl]
	r2 &= ~C_TimerEn
	[P_TimerD_Ctrl] = r2
L_BAM4_Sel?:			
	test r1,0x1000
	jz	L_BAM5_Sel?	
	r2 = [P_TimerE_Ctrl]
	r2 &= ~C_TimerEn
	[P_TimerE_Ctrl] = r2
L_BAM5_Sel?:	
	test r1,0x2000
	jz	L_None_Sel?
	r2 = [P_TimerF_Ctrl]
	r2 &= ~C_TimerEn
	[P_TimerF_Ctrl] = r2
L_None_Sel?:	
	retf			
	.endp	
	

	